.. _axes_grid-api-index:

Matplotlib axes_grid Toolkit
============================

.. currentmodule:: mpl_toolkits


.. note::
   AxesGrid toolkit has been a part of matplotlib since v
   0.99. Originally, the toolkit had a single namespace of
   *axes_grid*. In more recent version, the toolkit
   has divided into two separate namespace (*axes_grid1* and *axisartist*).
   While *axes_grid* namespace is maintained for the backward compatibility,
   use of *axes_grid1* and *axisartist* is recommended. 
   For the documentation on ``axes_grid``,
   see the `previous version of the docs 
   <https://matplotlib.org/2.0.1/mpl_toolkits/axes_grid/index.html#toolkit-axesgrid-index>`_.

.. toctree::
    :maxdepth: 1
    
    axes_grid1
    axisartist


